#include "py_common.hpp"
#include "var_geometry.hpp"

typedef var::item_store<real> module_store;

#define MODULE_NAME tracern
#include "ntracer_body.hpp"
